@@ -8,7 +8,8 @@ module.exports = {
   "roots": [
     "<rootDir>/public/app",
     "<rootDir>/public/test",
-    "<rootDir>/packages"
+    "<rootDir>/packages",
+    "<rootDir>/scripts",
   ],
   "testRegex": "(\\.|/)(test)\\.(jsx?|tsx?)$",
   "moduleFileExtensions": [
@@ -20,7 +21,8 @@ module.exports = {
   ],
   "setupFiles": [
     "./public/test/jest-shim.ts",
-    "./public/test/jest-setup.ts"
+    "./public/test/jest-setup.ts",
+    "jest-canvas-mock"
   ],
   "snapshotSerializers": ["enzyme-to-json/serializer"],
   "globals": { "ts-jest": { "isolatedModules": true } },
